#ifndef _LOGIKBUTTONS_H_
#define _LOGIKBUTTONS_H_

#include <qwidget.h>
#include <qbitmap.h>
#include <kwin/kwinbutton.h>

namespace KWinInternal
{
  class SideKapButton : public KWinWidgetButton
  {
    Q_OBJECT

    public:
      SideKapButton(QWidget * parent, const QString& tip);

      virtual ~SideKapButton();

      virtual QSize sizeHint() const;
      virtual QSize minimumSizeHint() const;

    protected:
      virtual void clickEvent(int button) = 0;

      void setBitmap(const QBitmap &);

      void mousePressEvent(QMouseEvent *);
      void mouseReleaseEvent(QMouseEvent *);
      void enterEvent(QEvent *);
      void leaveEvent(QEvent *);
      void paintEvent(QPaintEvent *);
      void resizeEvent(QResizeEvent *);

    private:
      QBitmap bitmap;

      bool mouseOver;
      bool mouseDown;
  };

  class SideKapButtonClose : public SideKapButton
  {
    Q_OBJECT

    public:
      SideKapButtonClose(QWidget * parent, const QString& tip);

    protected:
      virtual void clickEvent(int button);

    signals:
      void closeWindow();
  };

  class SideKapButtonHelp : public SideKapButton
  {
    Q_OBJECT

    public:
      SideKapButtonHelp(QWidget * parent, const QString& tip);

    protected:
      virtual void clickEvent(int button);

    signals:
      void help();
  };

  class SideKapButtonIconify : public SideKapButton
  {
    Q_OBJECT

    public:
      SideKapButtonIconify(QWidget * parent, const QString& tip);

    protected:
      virtual void clickEvent(int button);

    signals:
      void iconify();
  };

  class SideKapButtonLower : public SideKapButton
  {
    Q_OBJECT

    public:
      SideKapButtonLower(QWidget * parent, const QString& tip);

    protected:
      virtual void clickEvent(int button);

    signals:
      void lowerWindow();
  };

  class SideKapButtonMaximize : public SideKapButton
  {
    Q_OBJECT

    public:
      SideKapButtonMaximize(bool maximised, QWidget * parent, const QString& tip);

    protected:
      virtual void clickEvent(int button);

    protected slots:
      void slotMaximizeChange(bool);

    signals:
      void maximize(int mode);
  };

  class SideKapButtonSticky : public SideKapButton
  {
    Q_OBJECT

    public:
      SideKapButtonSticky(bool sticky, QWidget * parent, const QString& tip);

    protected:
      virtual void clickEvent(int button);

    protected slots:
      void slotStickyChange(bool);

    signals:
      void toggleSticky();
  };

  class SideKapButtonStaysOnTop : public SideKapButton
  {
    Q_OBJECT

    public:
      SideKapButtonStaysOnTop(QWidget * parent, const QString& tip);

    protected:
      virtual void clickEvent(int button);

    signals:
      void toggleStaysOnTop();
  };
}

#endif /* _LOGIKBUTTONS_H_ */

